pub enum KeyValSync {
No,
Files,
All,
}Variants
No
Do not call sync; fastest, but may end up with corrupt files in the database
Files
Call fsync on files before moving them in place inside the database. This should prevent the possibility for corrupt files, but does not guarantee that entries are persisted after returning from modifying functions.
All
Call fsync on files and then also on the containing dir. This should guarantee that changes are persisted by the time functions return.