pub struct Entry<'p, K: AsKey, V: DeserializeOwned + Serialize> { /* private fields */ }Expand description
Accessor for an entry, embeds an open file handle, allows to load or lock-and-delete etc.
Implementations
Sourceimpl<'p, K: AsKey, V: DeserializeOwned + Serialize> Entry<'p, K, V>
impl<'p, K: AsKey, V: DeserializeOwned + Serialize> Entry<'p, K, V>
pub fn target_path(&self) -> &Path
pub fn file_name(&self) -> &OsStr
Sourcepub fn key(&self) -> Result<K, KeyValError>
pub fn key(&self) -> Result<K, KeyValError>
Can return file name decoding errors for files that were inserted into the directory via other means than this library.
pub fn get(&mut self) -> Result<V, KeyValError>
Sourcepub fn take_lockable_file(&mut self) -> Option<LockableFile<File>>
pub fn take_lockable_file(&mut self) -> Option<LockableFile<File>>
Giving up the Entry accessor, means you have to call get
first. (Yes, locking wouldn’t protect that anyway! This lock
is not for that!) Returns None if already taken.
Sourcepub fn exists(&mut self) -> bool
pub fn exists(&mut self) -> bool
Whether the entry currently (still) exists – XX But there is no guarantee it is still the old one!
Sourcepub fn delete(&self) -> Result<bool, KeyValError>
pub fn delete(&self) -> Result<bool, KeyValError>
Returns whether a file deletion actually happened (concurrent
deletes might already have removed it). XX Same caveat as with
exists.