pub struct KeyVal<K: AsKey, V: DeserializeOwned + Serialize> {
pub config: KeyValConfig,
pub base_dir: PathBuf,
/* private fields */
}Fields
config: KeyValConfigbase_dir: PathBufImplementations
Sourceimpl<K: AsKey, V: DeserializeOwned + Serialize> KeyVal<K, V>
impl<K: AsKey, V: DeserializeOwned + Serialize> KeyVal<K, V>
pub fn open( base_dir: impl AsRef<Path>, config: KeyValConfig, signal_change: Option<PollingSignalsSender>, ) -> Result<Self, KeyValError>
pub fn lock_exclusive(&self) -> Result<ExclusiveFileLock<'_, File>, KeyValError>
Sourcepub fn insert(
&self,
key: &K,
val: &V,
exclusive: bool,
) -> Result<(), KeyValError>where
K: Debug,
pub fn insert(
&self,
key: &K,
val: &V,
exclusive: bool,
) -> Result<(), KeyValError>where
K: Debug,
Insert a mapping; if exclusive is true, give an error if
key is already in the map (otherwise the previous value is
silently overwritten).
Sourcepub fn delete(&self, key: &K) -> Result<bool, KeyValError>
pub fn delete(&self, key: &K) -> Result<bool, KeyValError>
Returns whether an entry was actually deleted (false means
that no entry for key existed)
Sourcepub fn entry_opt(&self, key: &K) -> Result<Option<Entry<'_, K, V>>, KeyValError>
pub fn entry_opt(&self, key: &K) -> Result<Option<Entry<'_, K, V>>, KeyValError>
Get access to an entry, if it exists. Note: does not lock,
and on Windows might possibly deadlock with the rename calls
of insert? Only tested on Linux (and macOS?)
Sourcepub fn get(&self, key: &K) -> Result<Option<V>, KeyValError>
pub fn get(&self, key: &K) -> Result<Option<V>, KeyValError>
Note: does not lock, and on Windows might possibly deadlock
with the rename calls of insert! Only tested on Linux (and
macOS?)
Sourcepub fn wait_for_entries(
&self,
stop_at: Option<SystemTime>,
) -> Result<bool, KeyValError>
pub fn wait_for_entries( &self, stop_at: Option<SystemTime>, ) -> Result<bool, KeyValError>
Stops waiting at stop_at if given. Returns true if it found
an entry, false if it timed out.
Sourcepub fn keys<'s>(
&'s self,
wait_for_entries: bool,
stop_at: Option<SystemTime>,
) -> Result<impl Iterator<Item = Result<K, KeyValError>> + use<'s, K, V>, KeyValError>
pub fn keys<'s>( &'s self, wait_for_entries: bool, stop_at: Option<SystemTime>, ) -> Result<impl Iterator<Item = Result<K, KeyValError>> + use<'s, K, V>, KeyValError>
Get all the keys contained in the map. Their order is not
defined. Note that the returned entries may not exist any more
by the time your code looks at them, since exclusivity can’t
be statically ensured, and taking a lock for the iterator’s
life time seems excessive. If wait_for_entries is true,
blocks until entries exist (but note that with concurrent
deletions, by the time the entries are read, they may be gone
again–the returned sequence might still be empty).
Sourcepub fn sorted_keys(
&self,
wait_for_entries: bool,
stop_at: Option<SystemTime>,
reverse: bool,
) -> Result<Vec<K>, KeyValError>where
K: Ord,
pub fn sorted_keys(
&self,
wait_for_entries: bool,
stop_at: Option<SystemTime>,
reverse: bool,
) -> Result<Vec<K>, KeyValError>where
K: Ord,
Sorted output of keys().